/**
 * Bridge or mutate to retext.
 *
 * ###### Notes
 *
 * *   if a [processor][] is given, uses its parser to create a new nlcst tree,
 *     then runs the plugins attached to with that ([*bridge mode*][bridge]);
 *     you can add a parser to processor for example with `retext-english`; other
 *     plugins used on the processor should be retext plugins
 * *   if a [parser][] is given, uses it to create a new nlcst tree, and returns
 *     it (*mutate mode*); you can get a parser by importing `Parser` from
 *     `retext-english` for example; other plugins used after `rehypeRetext`
 *     should be retext plugins
 *
 * @overload
 * @param {Processor} processor
 * @returns {TransformBridge}
 *
 * @overload
 * @param {Parser} parser
 * @returns {TransformMutate}
 *
 * @param {Parser | Processor} options
 *   Configuration (required).
 * @returns {TransformBridge | TransformMutate}
 *   Transform.
 */
export default function rehypeRetext(processor: Processor): TransformBridge;
/**
 * Bridge or mutate to retext.
 *
 * ###### Notes
 *
 * *   if a [processor][] is given, uses its parser to create a new nlcst tree,
 *     then runs the plugins attached to with that ([*bridge mode*][bridge]);
 *     you can add a parser to processor for example with `retext-english`; other
 *     plugins used on the processor should be retext plugins
 * *   if a [parser][] is given, uses it to create a new nlcst tree, and returns
 *     it (*mutate mode*); you can get a parser by importing `Parser` from
 *     `retext-english` for example; other plugins used after `rehypeRetext`
 *     should be retext plugins
 *
 * @overload
 * @param {Processor} processor
 * @returns {TransformBridge}
 *
 * @overload
 * @param {Parser} parser
 * @returns {TransformMutate}
 *
 * @param {Parser | Processor} options
 *   Configuration (required).
 * @returns {TransformBridge | TransformMutate}
 *   Transform.
 */
export default function rehypeRetext(parser: Parser): TransformMutate;
export type HastRoot = import('hast').Root;
export type ParserConstructor = import('hast-util-to-nlcst').ParserConstructor;
export type ParserInstance = import('hast-util-to-nlcst').ParserInstance;
export type NlcstRoot = import('nlcst').Root;
export type Processor = import('unified').Processor<NlcstRoot>;
export type VFile = import('vfile').VFile;
export type Parser = ParserConstructor | ParserInstance;
/**
 * Bridge-mode.
 *
 * Runs the destination with the new nlcst tree.
 * Discards result.
 */
export type TransformBridge = (tree: HastRoot, file: VFile) => Promise<undefined>;
/**
 * Mutate-mode.
 *
 * Further transformers run on the nlcst tree.
 */
export type TransformMutate = (tree: HastRoot, file: VFile) => NlcstRoot;
